#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""This is the yum plugin for the kamp-simon-shell-client.

It is NOT intended to be run directly!
"""


import os
from yum.plugins import TYPE_INTERACTIVE


requires_api_version = '2.7'
plugin_type = (TYPE_INTERACTIVE,)


# Called just after Yum has finished the RPM update transation.
def posttrans_hook(conduit):
    # Get flag file path from config.
    flag_file = conduit.confString('main', 'package_change_flag_file')

    # Check if flag file was set.
    if flag_file is None:
        conduit.error(2, 'No flag file given!')
        return

    # Get flag directory from flag file.
    flag_dir = os.path.dirname(flag_file)

    # Check if directory exists.
    if not os.path.isdir(flag_dir):
        try:
            # Create the directory and its parents.
            os.makedirs(flag_dir, 0777)
        except OSError as e:
            conduit.error(2, 'Error while creating directory {dirname}: {err}'.fomat(dirname=flag_dir, err=str(e)))
            return

    # Check if the file exists.
    if not os.path.isfile(flag_file):
        try:
            # Create the file by opening and closing it.
            open(flag_file, 'a').close()
        except OSError as e:
            conduit.error(2, 'Error while creating file {filename}: {err}'.fomat(filename=flag_file, err=str(e)))
            return

    try:
        # Set access and modified times to the current time.
        os.utime(flag_file, None)
    except OSError as e:
        conduit.error(2, 'Error while setting access and modified times of {filename}: {err}'.fomat(filename=flag_file, err=str(e)))
        return

    try:
        # Set directory permissions.
        os.chmod(flag_dir, 0777)
    except OSError as e:
        conduit.error(2, 'Error while setting directory permissions of {dirname}: {err}'.fomat(dirname=flag_dir, err=str(e)))
        return

    try:
        # Set file permissions.
        os.chmod(flag_file, 0666)
    except OSError as e:
        conduit.error(2, 'Error while setting file permissions of {filename}: {err}'.fomat(filename=flag_file, err=str(e)))
        return
